

 /*+-------------------------------------------------------+
   |          SUGI 29 Sample                               |
   |          SAS MAPPING: Tips and tricks                 |
   |                                                       |
   |    NAME: WebUSMap.sas                                 |
   |   TITLE: An interactive map using SAS/IntrNet.        |
   |          To use this example, you must have Intrnet   |
   |          installed and running on your server and     |
   |          you must modify the locations to match your  |
   |          system.  The SAS files must be moved to your |
   |          appsrv program location.  Check your Intrnet |
   |          documentation for further details.           |
   |          This program is launched from an html page   |
   |          (webmap.html).  This sas program generates   |
   |          an HTML page with a map on it and that html  |
   |          page calls this program with other options or|
   |          launches another program (webusmap2.sas).    |
   | PRODUCT: GRAPH                                        |
   |                                                       |
   |   NOTES: Last Update 19FEB04                          |
   |          This example outputs several ODS device types|
   |          You must run make_usstat.sas to create the   |
   |          dataset for this example.                    |
   |          All data and programs should be put in the   |
   |          App Server program location.  The webmap.html|
   |          file can go where every you want.            |
   |          You must modify the html file and sas files  |
   |          to match your system setup.                  |
   +-------------------------------------------------------+*/




 /*******************************************************************   
  * This sample program creates a map of the US with pop-up
  * text and drilldown linking.  The maps is created with 
  * the GMAP procedure.  GIF, Java and ActiveX output can
  * be created.
  *
  * The pop-up text and drilldown links are created by 
  * making a temporary copy of the statistics data set
  * and adding an html variable with the HREF and ALT
  * attributes.
  *
  * This program accepts the following input parameters:
  *
  *   PLOTVAR    one of:
  *                GROWTH (default)
  *                BIRTH
  *                DEATH
  *                INTMIG
  *                POP
  *                DOMMIG
  *
  *   PLOTTYPE   one of:
  *                GIF (default)
  *                JAVA
  *                ACTIVEX
  *                JAVAMETA
  *
  *   MAPWIDTH   width of map image in pixels (default 800)
  *
  *   MAPHEIGHT  height of map image in pixels (defaults to
  *                75% of map width)
  *
  *******************************************************************/   


ods listing close;
goptions reset;

/*******************************************************************/ 
/* SETUP.  Establish necessary locations for your system.          */
/*******************************************************************/     
/* location of dataset */
libname migdat '/dept/iss/sww_appsrv/v8/bip/test/mig/olddemo';
/* Set it to blank unless you have a path under _pgmlib */
%let _path=mig/olddemo/;
/* set this to the location of the sas java jar files */
%let _grafloc=http://sww.sas.com/avd/sasship;
%let MAPWIDTH=500; /*width of map*/



%global plottype plotvar mapwidth mapheight;
%global plotopt plottitle showvar codebase;


/*-----------------------------------------------------------------*/     
/* This macro sets up a map dataset if necessary, and processes the*/
/* input parameters and device drivers.                            */
/*-----------------------------------------------------------------*/       
%macro helper;
  /* APSWORK is a location that continues to exist until the */
  /* server is stopped.  We create it only when needed.  In a*/
  /* real world application, this data would be generated    */
  /* outside the App Server in a permanent location.         */
  %if %sysfunc(exist(APSWORK.USMAP)) %then 
    /* do nothing */ ;
  %else %do; 
    /* Build USMAP with state name. */ 
    data apswork.usmap;
      set maps.us;
      length statenam $ 20; 
      label statenam='State Name';
      statenam=fipnamel(state);
      run;
  %end; 


  /* process codebase and device info for the particular device */
  %let CODEBASE=%str("CODEBASE"="&_grafloc");
  %if %UPCASE(&plottype) eq JAVA %then
     %let plotopt=device=java;
  %else %if %UPCASE(&plottype) eq ACTIVEX %then %do;
     %let plotopt=device=activex;
     %let codebase=%str("CODEBASE"="&_grafloc/sasgraph.exe");
  %end;
  %else %if %UPCASE(&plottype) eq JAVAMETA %then %do;
     %let plotopt=device=javameta;
     %end;
  %else
     %let plotopt=device=gif;

  /* default to plot GROWTH if no plotvar specified */
  %if &plotvar eq %then
    %let plotvar=growth;

  /* set up pop-up formats and titles for selected plotvar */
  %if %UPCASE(&plotvar) eq POP %then %do;
    %let showvar=put(pop,COMMA11.0);
    %let plottitle='Population';
  %end;
  %else %if %UPCASE(&plotvar) eq GROWTH %then %do;
    %let showvar=put(growth*100,7.2) || '%';
    %let plottitle='Population Growth Rate';
  %end;
  %else %if %UPCASE(&plotvar) eq BIRTH %then %do;
    %let showvar=put(birth,7.2);
    %let plottitle='Birth Rate';
  %end;
  %else %if %UPCASE(&plotvar) eq DEATH %then %do;
    %let showvar=put(death,7.2);
    %let plottitle='Death Rate';
  %end;
  %else %if %UPCASE(&plotvar) eq INTMIG %then %do;
    %let showvar=put(intmig,7.2);
    %let plottitle='Net International Immigration';
  %end;
  %else %if %UPCASE(&plotvar) eq DOMMIG %then %do;
    %let showvar=put(dommig,7.2);
    %let plottitle='Net Domestic Immigration';
  %end;

  /* set default map width and height */
  %if &mapwidth eq %then %let mapwidth=700;
  %put mapwidth is "&mapwidth";
  %if &mapheight eq %then %let mapheight=%eval(&mapwidth*2/3);

%mend;
/*-----------------------------------------------------------------*/       

/* Run the macro */
%helper;


/*dump these values to the log so you can see what they are*/
%put &_URL;
%put &_service;
%put &_program;
%put &_pgmlib;
%put &_path;
%put &plotopt;
%put &plotvar;
%put &showvar;

/*******************************************************************/ 
/* Build a response dataset that includes drilldown links and alt  */
/* text.  The drilldown links run IntrNet to invoke the            */
/* webusmap2.sas program when you click on a state.                */
/*******************************************************************/ 
data ustemp;
  set migdat.USSTAT;
  html = 'href="' || "&_URL" || "?_service=&_service" || 
         '&_program=' || "&_pgmlib..&_path.webusmap2.sas" || 
         '&plotvar=' || left(trim("&plotvar"))||
         '&stateid=' || left(trim(state)) || 
          '" alt="' || trim(statenam) || ' ' || &showvar ||
          '"';
  run;


/*******************************************************************/ 
/* Setup ODS HTML to use with the App Dispatcher.                  */
/*******************************************************************/ 
ods html body=_webout path=&_tmpcat(url=&_replay) rs=none
  attributes=(&codebase) nogtitle nogfootnote;

goptions &plotopt xpixels=&mapwidth ypixels=&mapheight transparency;



/*******************************************************************/ 
/* Create a 'ramp' of colors from green to red for the map.        */
/*******************************************************************/ 
pattern1  v=s c=cx00ff00;
pattern2  v=s c=cx9aff00;
pattern3  v=s c=cxe0ff00;
pattern4  v=s c=cxffdd00;
pattern5  v=s c=cxffcd00;
pattern6  v=s c=cxff8700;
pattern7  v=s c=cxff0000;


/*******************************************************************/ 
/* Create the map with the title and variable selected.            */
/*******************************************************************/ 
title &plottitle;
title2 h=1 "(click on a state to drill down)";
proc gmap map=apswork.usmap data=work.ustemp;
  id statenam;
  choro &plotvar / html = html coutline=black;
  run; quit;

/* stop html output now */
ods html close;


/*******************************************************************/ 
/* Append html code that allows the user to select a new variable  */
/* or another device.  Done simply thru put statements.            */
/*******************************************************************/ 
%macro htmloption(var,value,label);
  %local sel;
  %if %UPCASE(&var) eq %UPCASE(&value) %then
    %let sel=%str( SELECTED);
  %else
    %let sel=;
  put '  <OPTION VALUE="' "&value" '"' "&sel>&label</OPTION>";
%mend;

data _null_;
  file _webout;
  put '<FORM METHOD="GET" ACTION="' "&_url" '"';
  put '   onSubmit="MAPWIDTH.value = ( navigator.appName.indexOf(' "'Microsoft') >= 0 ) ?"; 
  put '             document.body.clientWidth-20 : window.innerWidth-20;">';
  put '  <INPUT NAME="_PROGRAM" VALUE="' "&_program" '" TYPE="HIDDEN">';
  put '  <INPUT NAME="_SERVICE" VALUE="' "&_service" '" TYPE="HIDDEN">';
  put '  <INPUT NAME="MAPWIDTH" VALUE="' "&mapwidth" '" TYPE="HIDDEN">';
  put '<TABLE BORDER="0">';
  put '<TR><TD>Select data to plot:</TD>';
  put '<TD><SELECT NAME="PLOTVAR">';
  %htmloption(&PLOTVAR, GROWTH, Growth Rate);
  %htmloption(&PLOTVAR, BIRTH, Birth Rate);
  %htmloption(&PLOTVAR, DEATH, Death Rate);
  %htmloption(&PLOTVAR, DOMMIG, Net Domestic Immigration);
  %htmloption(&PLOTVAR, INTMIG, Net International Immigration);
  %htmloption(&PLOTVAR, POP, Population);
  put '</SELECT>';
  put '</TD>';
  put '<TD><INPUT TYPE="CHECKBOX" NAME="_DEBUG" VALUE="131">Show SAS Log</TD>';
  put '</TR>';
  put '<TR><TD>Select plot type:</TD>';
  put '<TD>';
  put '<SELECT NAME="PLOTTYPE">';
  %htmloption(&PLOTTYPE, GIF, GIF Image);
  %htmloption(&PLOTTYPE, JAVA, Java Applet);
  %htmloption(&PLOTTYPE, ACTIVEX, ActiveX Control);
  %htmloption(&PLOTTYPE, JAVAMETA, Metaview Applet);
  put '</SELECT>';
  put '</TD>';
  put '<TD><INPUT TYPE="SUBMIT" VALUE="Replot"></TD>';
  put '</TR>';
  put '</TABLE>';
  run;
