
 /*+-------------------------------------------------------+
   |          SUGI 29 Sample                               |
   |          SAS MAPPING: Tips and tricks                 |
   |                                                       |
   |    NAME: WebUSMap2.sas                                |
   |   TITLE: An interactive map using SAS/IntrNet.        |
   |          See WebUSMap.sas for more information.       |
   |          This program is launched by the html code    |
   |          created by webusmap.sas when you click on a  |
   |          state.  It displays all the data for the     |
   |          selected state and give a comparison graph   |
   |          of all states for the selected variable.     |
   | PRODUCT: GRAPH                                        |
   |                                                       |
   |   NOTES: Last Update 19FEB04                          |
   |          This example outputs several ODS device types|
   |          You must run make_usstat.sas to create the   |
   |          dataset for this example.                    |
   |          All data and programs should be put in the   |
   |          App Server program location.  The webmap.html|
   |          file can go where every you want.            |
   |          You must modify the html file and sas files  |
   |          to match your system setup.                  |
   +-------------------------------------------------------+*/

ods listing close;
goptions reset;

/*******************************************************************/ 
/* SETUP.  Establish necessary locations for your system.          */
/*******************************************************************/  
/* location of the dataset */   
libname migdat '/dept/iss/sww_appsrv/v8/bip/test/mig/olddemo';

%global stateid plotvar;



/*******************************************************************/ 
/* Setup ODS HTML to use with the App Dispatcher.                  */
/*******************************************************************/ 
ods html body=_webout path=&_tmpcat(url=&_replay) rs=none;
goptions device=gif;  /* this program always uses gif output */


/*-----------------------------------------------------------------*/   
/* This macro process a where statement for the selected state.    */  
/*-----------------------------------------------------------------*/     
%macro state_where_cls;
  %if &stateid ne %then
     (where=(state eq &stateid));
%mend;
/*-----------------------------------------------------------------*/     





/*******************************************************************/ 
/* Print the table of data to a web page.                          */
/*******************************************************************/ 
title "All Values for this State";
proc print data=migdat.USSTAT %state_where_cls label noobs;
  var state statenam pop growth birth death intmig dommig;
  run;  



%macro do_chart;
/* Don't do this in the general case, only when there is a state given */
%if &stateid ne %then %do;

/*******************************************************************/
/* Find the observation for this state so we can change the color  */
/* in the gchart for this state.                                   */
/*******************************************************************/
data _null_;
  set migdat.USSTAT;
  if (state = &stateid) then do;
     string='pattern' || left(trim(_n_)) || ' v=s c=cxff8700;';
     call symput('pattern',string);
  end;
run;


/*******************************************************************/ 
/* setup for and do a gchart comparison chart for all states.      */
/*******************************************************************/ 
goptions ftext=xswissb  ctext=black ypixels=1000 cback=ltgray; 

pattern1  v=s c=cx00ff00;
pattern2  v=s c=cx00ff00;
pattern3  v=s c=cx00ff00;
pattern4  v=s c=cx00ff00;
pattern5  v=s c=cx00ff00;
pattern6  v=s c=cx00ff00;
pattern7  v=s c=cx00ff00;
pattern8  v=s c=cx00ff00;
pattern9  v=s c=cx00ff00;
pattern10  v=s c=cx00ff00;
pattern11  v=s c=cx00ff00;
pattern12  v=s c=cx00ff00;
pattern13  v=s c=cx00ff00;
pattern14  v=s c=cx00ff00;
pattern15  v=s c=cx00ff00;
pattern16  v=s c=cx00ff00;
pattern17  v=s c=cx00ff00;
pattern18  v=s c=cx00ff00;
pattern19  v=s c=cx00ff00;
pattern20  v=s c=cx00ff00;
pattern21  v=s c=cx00ff00;
pattern22  v=s c=cx00ff00;
pattern23  v=s c=cx00ff00;
pattern24  v=s c=cx00ff00;
pattern25  v=s c=cx00ff00;
pattern26  v=s c=cx00ff00;
pattern27  v=s c=cx00ff00;
pattern28  v=s c=cx00ff00;
pattern29  v=s c=cx00ff00;
pattern30  v=s c=cx00ff00;
pattern31  v=s c=cx00ff00;
pattern32  v=s c=cx00ff00;
pattern33  v=s c=cx00ff00;
pattern34  v=s c=cx00ff00;
pattern35  v=s c=cx00ff00;
pattern36  v=s c=cx00ff00;
pattern37  v=s c=cx00ff00;
pattern38  v=s c=cx00ff00;
pattern39  v=s c=cx00ff00;
pattern40  v=s c=cx00ff00;
pattern41  v=s c=cx00ff00;
pattern42  v=s c=cx00ff00;
pattern43  v=s c=cx00ff00;
pattern44  v=s c=cx00ff00;
pattern45  v=s c=cx00ff00;
pattern46  v=s c=cx00ff00;
pattern47  v=s c=cx00ff00;
pattern48  v=s c=cx00ff00;
pattern49  v=s c=cx00ff00;
pattern50  v=s c=cx00ff00;
pattern51  v=s c=cx00ff00;

/*set this state to red*/
&pattern;

axis1 label=('State') value=(h=.75) ;
title font=swissb color=blue "%upcase(&plotvar) for all States";
proc gchart data=migdat.USSTAT;
  hbar statenam / sumvar=&plotvar type=mean 
                  patternid=midpoint maxis=axis1; 
  run; 
quit;
%end;
%mend;


/* run the chart if state specified */
%do_chart;

/* close the html */
ods html close;


