 /*+-------------------------------------------------------+
   |          SUGI 29 Sample                               |
   |          SAS MAPPING: Tips and tricks                 |
   |                                                       |
   |    NAME: shadow.sas                                   |
   |   TITLE: Add a drop shadow under the map.             |
   |          Create an annotate dataset of the US and draw|
   |          offset under the map to create a shadow      |
   |          effect.                                      |
   | PRODUCT: GRAPH                                        |
   |                                                       |
   |   NOTES: Last Update 24FEB04                          |
   |          This example outputs several ODS device types|
   +-------------------------------------------------------+*/



%let name=shadow;
filename odsout '.';
goptions reset=global;
/** Sets goptions xpixels and ypixels **/
%inc '../setsize.sas';

/***********************************************************************/    
/* Subset the US map to only include the 48 states                     */
/***********************************************************************/    
data work.states; 
 set maps.states (where=
  (fipstate(state) not in ('AK' 'HI' 'PR')
   and
  (density < 3))
 );
run;

/***********************************************************************/ 
/* Project the map to the right direction                              */
/***********************************************************************/ 
proc gproject data=work.states out=work.states dupok;
  id state;
run;

/***********************************************************************/ 
/* To create a shadow, you create an annotate dataset that displays    */
/* under the map.  Remove extra points before starting creating actual */
/* annotate dataset                                                    */
/***********************************************************************/ 
proc gremove data=work.states out=work.anno_shadow;
 by state; 
 id state;
run;


/***********************************************************************/ 
/* Create an annotate dataset of the outline of the US                 */
/***********************************************************************/ 
data work.anno_shadow;
   length color $ 8;
   length function $ 8;
   retain xsys '2' ysys '2' color 'gray88' size 1.75 style 'msolid';
   retain function firstx firsty;
   set work.anno_shadow; 
   by state segment;
   when='b'; /* before - so it draws before and 'under' the map */

   /*offset the data to give it a shadow look */
   x=x+.009; 
   y=y-.009;

   /* if this is the beginning of the segment, save the values */
   if first.segment then do;
      function = 'poly'; 
	  firstx = x;
	  firsty = y;
      end;
   else 
      function='Polycont';
   output;
   /* if the end of the segment, then close the polygon */
   if last.segment then do;
      x = firstx; 
      y = firsty; 
      output;
      end;
run;


/* ---------------------------------------------------------*/     
/* Declare a macro to do the map, for the specified device */
/* ---------------------------------------------------------*/     
%macro do_map(dev);

  GOPTIONS DEVICE=&dev;
  ODS LISTING CLOSE;
  ODS HTML path=odsout body="&name._&dev..html"
    ;

  pattern v=s c=CXE9E8DC r=100;
  goptions border ;
  title1 "Adding a Shadow to a map";

  proc gmap data=work.states map=work.states anno=work.anno_shadow; 
    id state; 
    choro state /  coutline=black
          nolegend name="&name"; 
  run;

  quit;
  ODS HTML CLOSE;
  ODS LISTING;
 
%mend do_map;

%do_map(gif);
%do_map(java);
%do_map(activex);

